@@ -25,18 +25,19 @@
 
 #include "filereceiver/filereceiver.h"
 
-#include <QtCore/QProcess>
+#include <QProcess>
 #include <QDBusServiceWatcher>
+#include <QDBusPendingReply>
 #include <QDBusMetaType>
+#include <QTimer>
+#include <QDebug>
+#include <QUrl>
 
-#include <kdemacros.h>
-#include <KDebug>
 #include <KAboutData>
-#include <KComponentData>
 #include <KPluginFactory>
+#include <KLocalizedString>
 #include <kfileplacesmodel.h>
 #include <kdirnotify.h>
-#include <ksharedconfig.h>
 
 #include <bluedevil/bluedevilmanager.h>
 #include <bluedevil/bluedeviladapter.h>
@@ -44,9 +45,9 @@
 
 using namespace BlueDevil;
 
-K_PLUGIN_FACTORY(BlueDevilFactory,
-                 registerPlugin<BlueDevilDaemon>();)
-K_EXPORT_PLUGIN(BlueDevilFactory("bluedevildaemon", "bluedevil"))
+K_PLUGIN_FACTORY_WITH_JSON(BlueDevilFactory,
+                           "bluedevil.json",
+                           registerPlugin<BlueDevilDaemon>();)
 
 Q_DECLARE_METATYPE(DeviceInfo)
 Q_DECLARE_METATYPE(QMapDeviceInfo)
@@ -63,9 +64,8 @@ struct BlueDevilDaemon::Private
     Adapter                         *m_adapter;
     QDBusServiceWatcher             *m_monolithicWatcher;
     FileReceiver                    *m_fileReceiver;
-    QTimer                          m_timer;
-    KComponentData                  m_componentData;
-    KSharedConfig::Ptr              m_config;
+    QList <DeviceInfo>               m_discovered;
+    QTimer                           m_timer;
 };
 
 BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
@@ -79,51 +79,35 @@ BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
     d->m_adapter = 0;
     d->m_placesModel = 0;
     d->m_fileReceiver = 0;
-    d->m_monolithicWatcher = new QDBusServiceWatcher("org.kde.bluedevilmonolithic"
+    d->m_monolithicWatcher = new QDBusServiceWatcher(QStringLiteral("org.kde.bluedevilmonolithic")
             , QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration, this);
+    d->m_timer.setInterval(20000);
     d->m_timer.setSingleShot(true);
-    d->m_config = KSharedConfig::openConfig("bluedevilglobalrc");
 
     KAboutData aboutData(
-        "bluedevildaemon",
-        "bluedevil",
-        ki18n("Bluetooth Daemon"),
+        QStringLiteral("bluedevildaemon"),
+        i18n("Bluetooth Daemon"),
         bluedevil_version,
-        ki18n("Bluetooth Daemon"),
-        KAboutData::License_GPL,
-        ki18n("(c) 2010, UFO Coders")
+        i18n("Bluetooth Daemon"),
+        KAboutLicense::GPL,
+        i18n("(c) 2010, UFO Coders")
     );
 
-    aboutData.addAuthor(ki18n("Alejandro Fiestas Olivares"), ki18n("Maintainer"), "afiestas@kde.org",
-        "http://www.afiestas.org");
+    aboutData.addAuthor(i18n("Alejandro Fiestas Olivares"), i18n("Maintainer"),
+                        QStringLiteral("afiestas@kde.org"), QStringLiteral("http://www.afiestas.org"));
 
-    aboutData.addAuthor(ki18n("Eduardo Robles Elvira"), ki18n("Maintainer"), "edulix@gmail.com",
-        "http://blog.edulix.es");
+    aboutData.addAuthor(i18n("Eduardo Robles Elvira"), i18n("Maintainer"),
+                        QStringLiteral("edulix@gmail.com"), QStringLiteral("http://blog.edulix.es"));
 
-    aboutData.setProgramIconName("preferences-system-bluetooth");
-    d->m_componentData = KComponentData(aboutData);
-    connect(d->m_monolithicWatcher, SIGNAL(serviceUnregistered(QString)), SLOT(monolithicFinished(QString)));
-    connect(&d->m_timer, SIGNAL(timeout()), SLOT(stopDiscovering()));
+    aboutData.setComponentName(QStringLiteral("bluedevil"));
+    KAboutData::registerPluginData(aboutData);
+
+    connect(d->m_monolithicWatcher, SIGNAL(serviceUnregistered(const QString &)), SLOT(monolithicFinished(const QString &)));
 
     connect(Manager::self(), SIGNAL(usableAdapterChanged(Adapter*)),
             this, SLOT(usableAdapterChanged(Adapter*)));
-    connect(Manager::self(), SIGNAL(adapterAdded(Adapter*)),
-            this, SLOT(adapterAdded(Adapter*)));
-    connect(Manager::self(), SIGNAL(adapterRemoved(Adapter*)),
-            this, SLOT(adapterRemoved(Adapter*)));
-
-    // Catch suspend/resume events
-    QDBusConnection::systemBus().connect("org.freedesktop.login1",
-                                         "/org/freedesktop/login1",
-                                         "org.freedesktop.login1.Manager",
-                                         "PrepareForSleep",
-                                         this,
-                                         SLOT(login1PrepareForSleep(bool))
-                                         );
 
     d->m_status = Private::Offline;
-
-    restoreAdaptersState();
     usableAdapterChanged(Manager::self()->usableAdapter());
 
     if (!Manager::self()->adapters().isEmpty()) {
@@ -133,8 +117,6 @@ BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
 
 BlueDevilDaemon::~BlueDevilDaemon()
 {
-    saveAdaptersState();
-
     if (d->m_status == Private::Online) {
         offlineMode();
     }
@@ -142,27 +124,6 @@ BlueDevilDaemon::~BlueDevilDaemon()
     delete d;
 }
 
-static Adapter *adapterForAddress(const QString &address)
-{
-    Q_FOREACH (Adapter *adapter, Manager::self()->adapters()) {
-        if (adapter->address() == address) {
-            return adapter;
-        }
-    }
-    return 0;
-}
-
-void BlueDevilDaemon::login1PrepareForSleep(bool active)
-{
-    if (active) {
-        kDebug(dblue()) << "About to suspend";
-        saveAdaptersState();
-    } else {
-        kDebug(dblue()) << "About to resume";
-        restoreAdaptersState();
-    }
-}
-
 bool BlueDevilDaemon::isOnline()
 {
     if (d->m_status == Private::Offline) {
@@ -171,75 +132,61 @@ bool BlueDevilDaemon::isOnline()
     return true;
 }
 
-QMapDeviceInfo BlueDevilDaemon::allDevices()
+QMapDeviceInfo BlueDevilDaemon::knownDevices()
 {
     QMapDeviceInfo devices;
-    QList<Device*> list = Manager::self()->usableAdapter()->devices();
 
-    Q_FOREACH (Device *const device, list) {
-        devices[device->address()] = deviceToInfo(device);
+    QList <Device* > list = Manager::self()->usableAdapter()->devices();
+    qCDebug(BLUEDAEMON) << "List: " << list.length();
+    DeviceInfo info;
+    Q_FOREACH(Device *const device, list) {
+        info[QStringLiteral("name")] = device->friendlyName();
+        info[QStringLiteral("icon")] = device->icon();
+        info[QStringLiteral("address")] = device->address();
+        info[QStringLiteral("UUIDs")] = device->UUIDs().join(QStringLiteral(","));
+        devices[device->address()] = info;
     }
 
-    return devices;
-}
+    if (!d->m_timer.isActive()) {
+        qCDebug(BLUEDAEMON) << "Start Discovery";
+        Manager::self()->usableAdapter()->startStableDiscovery();
+        d->m_discovered.clear();
+        d->m_timer.start();
+    }
 
-DeviceInfo BlueDevilDaemon::device(const QString &address)
-{
-    Q_FOREACH (Device *const device, Manager::self()->devices()) {
-        if (device->address() == address) {
-            return deviceToInfo(device);
+    Q_FOREACH(const DeviceInfo& info, d->m_discovered) {
+        if (!devices.contains(info[QStringLiteral("address")])) {
+            devices[info[QStringLiteral("address")]] = info;
         }
     }
-
-    return DeviceInfo();
-}
-
-void BlueDevilDaemon::startDiscovering(quint32 timeout)
-{
-    if (!d->m_adapter) {
-        return;
-    }
-
-    kDebug(dblue()) << "Start discovering for" << timeout << "ms";
-
-    d->m_adapter->startDiscovery();
-
-    if (timeout > 0) {
-        d->m_timer.start(timeout);
-    }
+    return devices;
 }
 
 void BlueDevilDaemon::stopDiscovering()
 {
-    if (!d->m_adapter) {
-        return;
-    }
-
-    kDebug(dblue()) << "Stop discovering";
-
-    if (d->m_adapter->isDiscovering()) {
-        d->m_adapter->stopDiscovery();
-    }
+    qCDebug(BLUEDAEMON) << "Stopping discovering";
+    d->m_timer.stop();
+    Manager::self()->usableAdapter()->stopDiscovery();
 }
 
 void BlueDevilDaemon::executeMonolithic()
 {
-    kDebug(dblue());
+    qCDebug(BLUEDAEMON);
 
     QProcess process;
-    if (!process.startDetached("bluedevil-monolithic")) {
-        kError() << "Could not start bluedevil-monolithic";
+    if (!process.startDetached(QStringLiteral("bluedevil-monolithic"))) {
+        qCritical() << "Could not start bluedevil-monolithic";
     }
 }
 
 void BlueDevilDaemon::killMonolithic()
 {
-    kDebug(dblue());
+    qCDebug(BLUEDAEMON);
     QDBusMessage msg = QDBusMessage::createMethodCall(
-        "org.kde.bluedevilmonolithic",
-        "/MainApplication",
-        "org.kde.KApplication",
-        "quit"
+        QStringLiteral("org.kde.bluedevilmonolithic"),
+        QStringLiteral("/MainApplication"),
+        QStringLiteral("org.kde.KApplication"),
+        QStringLiteral("quit")
     );
     QDBusPendingCall pending = QDBusConnection::sessionBus().asyncCall(msg);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pending);
@@ -248,22 +195,24 @@ void BlueDevilDaemon::killMonolithic()
 
 void BlueDevilDaemon::onlineMode()
 {
-    kDebug(dblue());
+    qCDebug(BLUEDAEMON);
     if (d->m_status == Private::Online) {
-        kDebug(dblue()) << "Already in onlineMode";
+        qCDebug(BLUEDAEMON) << "Already in onlineMode";
         return;
     }
 
     d->m_bluezAgent = new BluezAgent(new QObject());
     connect(d->m_bluezAgent, SIGNAL(agentReleased()), this, SLOT(agentReleased()));
-    connect(d->m_adapter, SIGNAL(deviceFound(Device*)), this, SLOT(deviceFound(Device*)));
 
-    FileReceiverSettings::self()->readConfig();
+    connect(d->m_adapter, SIGNAL(deviceFound(Device*)), this, SLOT(deviceFound(Device*)));
+    connect(&d->m_timer, SIGNAL(timeout()), d->m_adapter, SLOT(stopDiscovery()));
+
+    FileReceiverSettings::self()->load();
     if (!d->m_fileReceiver && FileReceiverSettings::self()->enabled()) {
-        d->m_fileReceiver = new FileReceiver(d->m_componentData, this);
+        d->m_fileReceiver = new FileReceiver(this);
     }
     if (d->m_fileReceiver && !FileReceiverSettings::self()->enabled()) {
-        kDebug(dblue()) << "Stoppping server";
+        qCDebug(BLUEDAEMON) << "Stoppping server";
         delete d->m_fileReceiver;
         d->m_fileReceiver = 0;
     }
@@ -272,14 +221,14 @@ void BlueDevilDaemon::onlineMode()
         d->m_placesModel = new KFilePlacesModel();
     }
 
-    //Just in case kded4 was killed or crashed
-    QModelIndex index = d->m_placesModel->closestItem(KUrl("bluetooth:/"));
+    //Just in case kded was killed or crashed
+    QModelIndex index = d->m_placesModel->closestItem(QUrl(QStringLiteral("bluetooth:/")));
     while (index.row() != -1) {
         d->m_placesModel->removePlace(index);
-        index = d->m_placesModel->closestItem(KUrl("bluetooth:/"));
+        index = d->m_placesModel->closestItem(QUrl(QStringLiteral("bluetooth:/")));
     }
 
-    d->m_placesModel->addPlace("Bluetooth", KUrl("bluetooth:/"), "preferences-system-bluetooth");
+    d->m_placesModel->addPlace(QStringLiteral("Bluetooth"), QUrl(QStringLiteral("bluetooth:/")), QStringLiteral("preferences-system-bluetooth"));
 
     executeMonolithic();
 
@@ -288,7 +237,7 @@ void BlueDevilDaemon::onlineMode()
 
 void BlueDevilDaemon::monolithicFinished(const QString &)
 {
-    kDebug(dblue());
+    qCDebug(BLUEDAEMON);
 
     if (d->m_status == Private::Online) {
         executeMonolithic();
@@ -297,9 +246,9 @@ void BlueDevilDaemon::monolithicFinished(const QString &)
 
 void BlueDevilDaemon::offlineMode()
 {
-    kDebug(dblue()) << "Offline mode";
+    qCDebug(BLUEDAEMON) << "Offline mode";
     if (d->m_status == Private::Offline) {
-        kDebug(dblue()) << "Already in offlineMode";
+        qCDebug(BLUEDAEMON) << "Already in offlineMode";
         return;
     }
 
@@ -311,17 +260,20 @@ void BlueDevilDaemon::offlineMode()
     }
 
     if (d->m_fileReceiver) {
-        kDebug(dblue()) << "Stoppping server";
+        qCDebug(BLUEDAEMON) << "Stoppping server";
         delete d->m_fileReceiver;
         d->m_fileReceiver = 0;
     }
 
     //Just to be sure that online was called
     if (d->m_placesModel)  {
-        QModelIndex index = d->m_placesModel->closestItem(KUrl("bluetooth:/"));
+        QModelIndex index = d->m_placesModel->closestItem(QUrl(QStringLiteral("bluetooth:/")));
         d->m_placesModel->removePlace(index);
     }
 
+    if (BlueDevil::Manager::self()->adapters().isEmpty()) {
+        killMonolithic();
+    }
     d->m_status = Private::Offline;
 }
 
@@ -349,85 +301,35 @@ void BlueDevilDaemon::usableAdapterChanged(Adapter *adapter)
     }
 }
 
-void BlueDevilDaemon::adapterAdded(Adapter *adapter)
-{
-    restoreAdapterState(adapter);
-}
-
-void BlueDevilDaemon::adapterRemoved(Adapter *adapter)
-{
-    Q_UNUSED(adapter)
-
-    if (BlueDevil::Manager::self()->adapters().isEmpty()) {
-        killMonolithic();
-    }
-}
-
 void BlueDevilDaemon::deviceFound(Device *device)
 {
-    kDebug(dblue()) << "DeviceFound: " << device->name();
-    org::kde::KDirNotify::emitFilesAdded("bluetooth:/");
+    qCDebug(BLUEDAEMON) << "DeviceFound: " << device->name();
+    d->m_discovered.append(deviceToInfo(device));
+    org::kde::KDirNotify::emitFilesAdded(QUrl(QStringLiteral("bluetooth:/")));
 }
 
 void BlueDevilDaemon::monolithicQuit(QDBusPendingCallWatcher* watcher)
 {
-    kDebug(dblue());
+    qCDebug(BLUEDAEMON);
     QDBusPendingReply<void> reply = *watcher;
     if (reply.isError()) {
         qDebug() << "Error response: " << reply.error().message();
+        killMonolithic();
     }
 }
 
-void BlueDevilDaemon::saveAdaptersState()
-{
-    Manager *manager = Manager::self();
-    if (!manager) {
-        return;
-    }
-
-    KConfigGroup adaptersGroup = d->m_config->group("Adapters");
-
-    Q_FOREACH (Adapter *adapter, manager->adapters()) {
-        const QString key = QString("%1_powered").arg(adapter->address());
-        adaptersGroup.writeEntry<bool>(key, adapter->isPowered());
-    }
-
-    d->m_config->sync();
-}
-
-// New adapters are automatically powered on
-void BlueDevilDaemon::restoreAdaptersState()
-{
-    Manager *manager = Manager::self();
-    if (!manager) {
-        return;
-    }
-
-    KConfigGroup adaptersGroup = d->m_config->group("Adapters");
-
-    Q_FOREACH (Adapter *adapter, manager->adapters()) {
-        const QString key = QString("%1_powered").arg(adapter->address());
-        adapter->setPowered(adaptersGroup.readEntry<bool>(key, true));
-    }
-}
-
-void BlueDevilDaemon::restoreAdapterState(Adapter *adapter)
-{
-    KConfigGroup adaptersGroup = d->m_config->group("Adapters");
-
-    const QString key = QString("%1_powered").arg(adapter->address());
-    adapter->setPowered(adaptersGroup.readEntry<bool>(key, true));
-}
-
 DeviceInfo BlueDevilDaemon::deviceToInfo(Device *const device) const
 {
     DeviceInfo info;
-    info["name"] = device->friendlyName();
-    info["icon"] = device->icon();
-    info["address"] = device->address();
-    info["UBI"] = device->UBI();
-    info["UUIDs"] = device->UUIDs().join(",");
+    info[QStringLiteral("name")] = device->friendlyName();
+    info[QStringLiteral("icon")] = device->icon();
+    info[QStringLiteral("address")] = device->address();
+    info[QStringLiteral("discovered")] = QStringLiteral("true");
+    info[QStringLiteral("UUIDs")] = device->UUIDs().join(QStringLiteral(","));
+
     return info;
 }
 
-extern int dblue() { static int s_area = KDebug::registerArea("BlueDaemon", false); return s_area; }
+Q_LOGGING_CATEGORY(BLUEDAEMON, "BlueDaemon")
+
+#include "BlueDevilDaemon.moc"
