@@ -20,24 +20,17 @@
 #define FILE_RECEIVER_H
 
 #include <QObject>
-#include <KComponentData>
-
-#include "obex_agent_manager.h"
 
 class QDBusPendingCallWatcher;
 class FileReceiver : public QObject
 {
     Q_OBJECT
     public:
-        explicit FileReceiver(const KComponentData &componentData, QObject* parent = 0);
+        explicit FileReceiver(QObject* parent = 0);
         virtual ~FileReceiver();
 
     private Q_SLOTS:
-        void registerAgent();
         void agentRegistered(QDBusPendingCallWatcher* call);
-
-    private:
-        org::bluez::obex::AgentManager1 *m_agentManager;
 };
 
 #endif //FILE_RECEIVER_H
