@@ -21,28 +21,24 @@
 #ifndef SENDFILEITEMACTION_H
 #define SENDFILEITEMACTION_H
 
-#include <kfileitemactionplugin.h>
+#include <KAbstractFileItemActionPlugin>
 #include <KFileItemListProperties>
 
-#include "kded_bluedevil.h"
-
 class QAction;
-class KFileItemListProperties;
 class QWidget;
 
-class SendFileItemAction : public KFileItemActionPlugin
+class SendFileItemAction : public KAbstractFileItemActionPlugin
 {
-    Q_OBJECT
+Q_OBJECT
 public:
     SendFileItemAction(QObject* parent, const QVariantList &args);
-    virtual QList<QAction*> actions(const KFileItemListProperties &fileItemInfos, QWidget *parentWidget) const;
+    virtual QList< QAction* > actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget);
 
 private Q_SLOTS:
     void deviceTriggered();
     void otherTriggered();
 
 private:
-    org::kde::BlueDevil *m_kded;
     KFileItemListProperties m_fileItemInfos;
 };
 
