@@ -22,16 +22,20 @@
 #include "version.h"
 
 #include <QHash>
+#include <QDebug>
 #include <QDBusConnection>
 
-#include <kdemacros.h>
-#include <KDebug>
 #include <KAboutData>
 #include <KPluginFactory>
+#include <KLocalizedString>
 
-K_PLUGIN_FACTORY(ObexFtpFactory,
-                 registerPlugin<ObexFtpDaemon>();)
-K_EXPORT_PLUGIN(ObexFtpFactory("obexftpdaemon", "obexftpdaemon"))
+#include <bluedevil/bluedevilmanager.h>
+#include <bluedevil/bluedeviladapter.h>
+
+using namespace BlueDevil;
+K_PLUGIN_FACTORY_WITH_JSON(ObexFtpFactory,
+                           "obexftpdaemon.json",
+                           registerPlugin<ObexFtpDaemon>();)
 
 struct ObexFtpDaemon::Private
 {
@@ -54,34 +58,37 @@ ObexFtpDaemon::ObexFtpDaemon(QObject *parent, const QList<QVariant>&)
     qDBusRegisterMetaType<DBusManagerStruct>();
     qDBusRegisterMetaType<QVariantMapMap>();
 
-    KAboutData aboutData(
-        "obexftpdaemon",
-        "bluedevil",
-        ki18n("ObexFtp Daemon"),
-        bluedevil_version,
-        ki18n("ObexFtp Daemon"),
-        KAboutData::License_GPL,
-        ki18n("(c) 2010, UFO Coders")
-    );
-
-    aboutData.addAuthor(ki18n("Alejandro Fiestas Olivares"), ki18n("Maintainer"), "afiestas@kde.org",
-        "http://www.afiestas.org");
-
     d->m_status = Private::Offline;
-    d->m_interface = new OrgFreedesktopDBusObjectManagerInterface("org.bluez.obex", "/", QDBusConnection::sessionBus(), this);
+
+    KAboutData aboutData(QStringLiteral("obexftpdaemon"),
+                         i18n("ObexFtp Daemon"),
+                         bluedevil_version,
+                         i18n("ObexFtp Daemon"),
+                         KAboutLicense::GPL,
+                         i18n("(c) 2010, UFO Coders"));
+
+    aboutData.addAuthor(i18n("Alejandro Fiestas Olivares"), i18n("Maintainer"),
+                        QStringLiteral("afiestas@kde.org"), QStringLiteral("http://www.afiestas.org"));
+
+    connect(Manager::self(), SIGNAL(usableAdapterChanged(Adapter*)),
+            SLOT(usableAdapterChanged(Adapter*)));
+
+    d->m_interface = new OrgFreedesktopDBusObjectManagerInterface(QStringLiteral("org.bluez.obex"),
+                                                                  QStringLiteral("/"),
+                                                                  QDBusConnection::sessionBus(), this);
+
     connect(d->m_interface, SIGNAL(InterfacesRemoved(QDBusObjectPath,QStringList)),
             SLOT(interfaceRemoved(QDBusObjectPath,QStringList)));
 
-    d->m_serviceWatcher = new QDBusServiceWatcher("org.bluez.obex", QDBusConnection::sessionBus(),
-            QDBusServiceWatcher::WatchForRegistration | QDBusServiceWatcher::WatchForUnregistration, this);
+    d->m_serviceWatcher = new QDBusServiceWatcher(QStringLiteral("org.bluez.obex"),
+                                                  QDBusConnection::sessionBus(),
+                                                  QDBusServiceWatcher::WatchForUnregistration, this);
 
-    connect(d->m_serviceWatcher, SIGNAL(serviceRegistered(QString)), SLOT(serviceRegistered()));
-    connect(d->m_serviceWatcher, SIGNAL(serviceUnregistered(QString)), SLOT(serviceUnregistered()));
+    connect(d->m_serviceWatcher, SIGNAL(serviceUnregistered(QString)), SLOT(serviceUnregistered(QString)));
 
-    if (QDBusConnection::sessionBus().interface()->isServiceRegistered("org.bluez.obex")) {
+    //WARNING this blocks if org.bluez in system bus is dead
+    if (Manager::self()->usableAdapter()) {
         onlineMode();
-    } else {
-        offlineMode();
     }
 }
 
@@ -95,9 +102,9 @@ ObexFtpDaemon::~ObexFtpDaemon()
 
 void ObexFtpDaemon::onlineMode()
 {
-    kDebug(dobex());
+    qCDebug(OBEXDAEMON);
     if (d->m_status == Private::Online) {
-        kDebug(dobex()) << "Already in onlineMode";
+        qCDebug(OBEXDAEMON) << "Already in onlineMode";
         return;
     }
 
@@ -106,9 +113,9 @@ void ObexFtpDaemon::onlineMode()
 
 void ObexFtpDaemon::offlineMode()
 {
-    kDebug(dobex());
+    qCDebug(OBEXDAEMON) << "Offline mode";
     if (d->m_status == Private::Offline) {
-        kDebug(dobex()) << "Already in offlineMode";
+        qCDebug(OBEXDAEMON) << "Already in offlineMode";
         return;
     }
 
@@ -118,28 +125,33 @@ void ObexFtpDaemon::offlineMode()
     d->m_status = Private::Offline;
 }
 
-bool ObexFtpDaemon::isOnline()
+void ObexFtpDaemon::usableAdapterChanged(Adapter *adapter)
 {
-    return d->m_status == Private::Online;
+    if (!adapter) {
+        offlineMode();
+        return;
+    }
+
+    onlineMode();
 }
 
-QString ObexFtpDaemon::session(const QString &address, const QString &target, const QDBusMessage& msg)
+QString ObexFtpDaemon::session(QString address, const QDBusMessage& msg)
 {
+    qCDebug(OBEXDAEMON) << address;
+    address.replace(QLatin1Char('-'), QLatin1Char(':'));
+
     if (d->m_sessionMap.contains(address)) {
         return d->m_sessionMap[address];
     }
 
-    kDebug(dobex()) << "Creating session for" << address << "target" << target;
-
-    // At this point we always want delayed reply
+    //At this point we always want delayed reply
     msg.setDelayedReply(true);
-
     if (d->m_wipSessions.contains(address)) {
         d->m_wipSessions[address]->addMessage(msg);
         return QString();
     }
 
-    CreateSessionJob *job = new CreateSessionJob(address, target, msg);
+    CreateSessionJob *job = new CreateSessionJob(address, msg);
     connect(job, SIGNAL(finished(KJob*)), SLOT(sessionCreated(KJob*)));
     job->start();
 
@@ -147,60 +159,46 @@ QString ObexFtpDaemon::session(const QString &address, const QString &target, co
     return QString();
 }
 
-bool ObexFtpDaemon::cancelTransfer(const QString &transfer)
-{
-    // We need this function because kio_obexftp is not owner of the transfer,
-    // and thus cannot cancel it.
-
-    QDBusMessage call = QDBusMessage::createMethodCall("org.bluez.obex",
-                            transfer,
-                            "org.bluez.obex.Transfer1",
-                            "Cancel");
-
-    QDBusReply<void> reply = QDBusConnection::sessionBus().call(call);
-    return reply.isValid();
-}
-
 void ObexFtpDaemon::sessionCreated(KJob* job)
 {
     CreateSessionJob* cJob = qobject_cast<CreateSessionJob*>(job);
-    kDebug(dobex()) << cJob->path();
+    qCDebug(OBEXDAEMON) << cJob->path();
 
     d->m_wipSessions.remove(cJob->address());
+    d->m_sessionMap.insert(cJob->address(), cJob->path());
+    d->m_reverseSessionMap.insert(cJob->path(), cJob->address());
 
-    Q_FOREACH (const QDBusMessage &msg, cJob->messages()) {
+    const QList<QDBusMessage> messages = cJob->messages();
+    Q_FOREACH(const QDBusMessage &msg, messages) {
         QDBusMessage reply = msg.createReply(cJob->path());
-        QDBusConnection::sessionBus().send(reply);
-    }
-
-    if (!cJob->error()) {
-        d->m_sessionMap.insert(cJob->address(), cJob->path());
-        d->m_reverseSessionMap.insert(cJob->path(), cJob->address());
+        QDBusConnection::sessionBus().asyncCall(reply);
     }
 }
 
-void ObexFtpDaemon::serviceRegistered()
+void ObexFtpDaemon::serviceUnregistered(const QString& service)
 {
-    onlineMode();
-}
+    if (service != QLatin1String("org.bluez.obex")) {
+        return;
+    }
 
-void ObexFtpDaemon::serviceUnregistered()
-{
-    offlineMode();
+    d->m_sessionMap.clear();
+    d->m_reverseSessionMap.clear();
 }
 
 void ObexFtpDaemon::interfaceRemoved(const QDBusObjectPath &dbusPath, const QStringList& interfaces)
 {
-    kDebug(dobex()) << dbusPath.path() << interfaces;
+    qCDebug(OBEXDAEMON) << dbusPath.path() << interfaces;
     const QString path = dbusPath.path();
     if (!d->m_reverseSessionMap.contains(path)) {
-        kDebug(dobex()) << d->m_reverseSessionMap;
+        qCDebug(OBEXDAEMON) << d->m_reverseSessionMap;
         return;
     }
 
     QString address = d->m_reverseSessionMap.take(path);
-    kDebug(dobex()) << address;
-    kDebug(dobex()) << d->m_sessionMap.remove(address);
+    qCDebug(OBEXDAEMON) << address;
+    qCDebug(OBEXDAEMON) << d->m_sessionMap.remove(address);
 }
 
-extern int dobex() { static int s_area = KDebug::registerArea("ObexDaemon", false); return s_area; }
+Q_LOGGING_CATEGORY(OBEXDAEMON, "ObexDaemon")
+
+#include "ObexFtpDaemon.moc"
