@@ -20,7 +20,6 @@
  * Boston, MA 02110-1301, USA.                                               *
  *****************************************************************************/
 
-
 #ifndef SSPPAIRINGPAGE_H
 #define SSPPAIRINGPAGE_H
 
@@ -38,8 +37,7 @@ namespace BlueDevil {
 
 using namespace BlueDevil;
 
-class SSPPairingPage : public QWizardPage
-, Ui::SSPPairing
+class SSPPairingPage : public QWizardPage, Ui::SSPPairing
 {
 Q_OBJECT
 
@@ -51,14 +49,13 @@ public:
     virtual bool validatePage();
 
 public Q_SLOTS:
-    void registered(Device *device);
     void confirmationRequested(quint32 passkey, const QDBusMessage &msg);
     void pairedChanged(bool paired);
     void matchesClicked();
     void notMatchClicked();
+    void pinRequested(const QString &pin);
 
 protected:
-    Device* deviceFromWizard();
     QList <QWizard::WizardButton> wizardButtonsLayout() const;
 
 private:
@@ -68,4 +65,4 @@ private:
     KPixmapSequenceOverlayPainter *m_working;
 };
 
-#endif // SSPPAIRINGPAGE_H
\ No newline at end of file
+#endif // SSPPAIRINGPAGE_H
